searchData={"content_type":"text/markdown","items":[{"doc":"Command line interface for checking payment card account number brands.\n\nBuild using mix escript.build from project root.","ref":"Commandline.CLI.html","title":"Commandline.CLI","type":"module"},{"doc":"iex> ./simplecardbrand 41111111111111111\n    {:ok, :visa}\n\n    iex> ./simplecardbrand 41111111111111111 7111111111111111 8331111111111111111\n    {:ok, :visa}\n    {:ok, :gpn}\n    {:error, {:pan_unknown, \"Unknown card brand.\"}}","ref":"Commandline.CLI.html#module-examples","title":"Examples - Commandline.CLI","type":"module"},{"doc":"","ref":"Commandline.CLI.html#main/1","title":"Commandline.CLI.main/1","type":"function"},{"doc":"Identify the card brand from the PAN or the first six or  eight (UkrCard) PAN digits.\nThe PAN must contain only digits without leading or trailing spaces.\n\nSupports:\n- American Express (:americanexpress)\n- BORICA (:borica)\n- China T-Union (:chinatunion)\n- China UnionPay (:chinaunionpay)\n- Dankort (:dankort)\n- Diners Club (:dinersclub)\n- Diners Club International (:dinersclubinternational)\n- Discover (:discover)\n- GPN (:gpn)\n- Humo (:humo)\n- InstaPayment (:instapayment)\n- InterPayment (:interpayment)\n- JCB: (:jcb)\n- LankaPay: (:lankapay)\n- Maestro (:maestro)\n- Maestro UK (:maestrouk)\n- Mastercard (:mastercard)\n- Mir (:mir)\n- Napas (:napas)\n- RuPay (:rupay)\n- Troy (:troy)\n- UATP (:uatp)\n- UkrCard (:ukrcard)\n- UzCard (:uzcard)\n- Verve (:verve)\n- Visa (:visa)\n- Visa Electron (:visaelectron)\n\nRules as per: https://en.wikipedia.org/wiki/Payment_card_number","ref":"SimpleCardBrand.html","title":"SimpleCardBrand","type":"module"},{"doc":"Identify the card brand from the `pan`.","ref":"SimpleCardBrand.html#card_brand/1","title":"SimpleCardBrand.card_brand/1","type":"function"},{"doc":"iex> SimpleCardBrand.card_brand(\"4111111111111111\")\n    {:ok, :visa}\n\n    iex> SimpleCardBrand.card_brand(\"6040010012121161819\")\n    {:ok, :ukrcard}\n\n    iex> SimpleCardBrand.card_brand(\"5060994444444416\")\n    {:ok, :verve}\n\n    iex> SimpleCardBrand.card_brand(\"41111111111\")\n    {:error, {:pan_too_short, \"Minimum PAN length is 12, found 11.\"}}\n\n    iex> SimpleCardBrand.card_brand(\"41111111111111111120\")\n    {:error, {:pan_too_long, \"Maximum PAN length is 19, found 20.\"}}","ref":"SimpleCardBrand.html#card_brand/1-examples","title":"Examples - SimpleCardBrand.card_brand/1","type":"function"},{"doc":"Identify the card brand from a full or partial `pan` and the actual PAN length.\nUseful when identifying brands from previously-stored PANs.\n\nCheck for UkrCard and Verve early.","ref":"SimpleCardBrand.html#card_brand/2","title":"SimpleCardBrand.card_brand/2","type":"function"},{"doc":"iex> SimpleCardBrand.card_brand(\"411111\", 16)\n    {:ok, :visa}\n\n    iex> SimpleCardBrand.card_brand(\"6040010012\", 18)\n    {:ok, :ukrcard}\n\n    iex> SimpleCardBrand.card_brand(\"50609944444\", 19)\n    {:ok, :verve}\n\n    iex> SimpleCardBrand.card_brand(\"4111111111111111\", 10)\n    {:error, {:pan_too_short,\"Minimum PAN length is 12, found 10.\"}}\n\n    iex> SimpleCardBrand.card_brand(\"0123456789012345678\")\n    {:error, {:pan_unknown,\"Unknown card brand.\"}}","ref":"SimpleCardBrand.html#card_brand/2-examples","title":"Examples - SimpleCardBrand.card_brand/2","type":"function"},{"doc":"Guard macros.","ref":"SimpleCardBrand.Guards.html","title":"SimpleCardBrand.Guards","type":"module"},{"doc":"Compare the first eight (8) digits of the `pan` against the UkrCard range.\nUse in guards where `pan` is known to be bytes.","ref":"SimpleCardBrand.Guards.html#is_ukrcard/1","title":"SimpleCardBrand.Guards.is_ukrcard/1","type":"macro"},{"doc":"iex> SimpleCardBrand.Guards.is_ukrcard(\"60420099123212\")\n    true\n\n    iex> SimpleCardBrand.Guards.is_ukrcard(\"6042010022222\")\n    false","ref":"SimpleCardBrand.Guards.html#is_ukrcard/1-examples","title":"Examples - SimpleCardBrand.Guards.is_ukrcard/1","type":"macro"},{"doc":"Compare the first six (6) digits of the `pan` against the Verve brand range.\nUse in guards where `pan` is known to be bytes.","ref":"SimpleCardBrand.Guards.html#is_verve/1","title":"SimpleCardBrand.Guards.is_verve/1","type":"macro"},{"doc":"iex> SimpleCardBrand.Guards.is_verve(\"506099212121\")\n    true\n\n    iex> SimpleCardBrand.Guards.is_verve(\"50609123\")\n    false","ref":"SimpleCardBrand.Guards.html#is_verve/1-examples","title":"Examples - SimpleCardBrand.Guards.is_verve/1","type":"macro"},{"doc":"Check the PAN length is in the minimum to maximum allowed length (inclusive).\nUse in guards where `pan_length` is known to be an integer.","ref":"SimpleCardBrand.Guards.html#pan_range/3","title":"SimpleCardBrand.Guards.pan_range/3","type":"macro"},{"doc":"iex> SimpleCardBrand.Guards.pan_range(16, 12, 19)\n    true\n\n    iex> SimpleCardBrand.Guards.pan_range(16, 19, 19)\n    false","ref":"SimpleCardBrand.Guards.html#pan_range/3-examples","title":"Examples - SimpleCardBrand.Guards.pan_range/3","type":"macro"},{"doc":"# CHANGELOG","ref":"changelog.html","title":"CHANGELOG","type":"extras"},{"doc":"- CLI for `card_brand/2`.\n- Add GitHub workflow.","ref":"changelog.html#0-4-0-2023-08-xx","title":"0.4.0 -- 2023-08-XX - CHANGELOG","type":"extras"},{"doc":"- Return reason tuple on error.\n  - `{:error, {:pan_too_short,\"Minimum PAN length is 12, found 10.\"}}`\n  - `{:error, {:pan_unknown,\"Unknown card brand.\"}}`\n  - `{:error, {:pan_too_long, \"Maximum PAN length is 19, found 20.\"}}`\n- Replace Erlang binary/bytes types with String.t in @spec's.\n- Add README and CHANGELOG to Hex docs.\n- Add pre-commit tasks.\n- Add command-line interface.","ref":"changelog.html#0-3-0-2023-08-08","title":"0.3.0 - 2023-08-08 - CHANGELOG","type":"extras"},{"doc":"- Minor credo refactors.\n- Brands: Dankort, GPN, LankaPay, Troy, UkrCard, Verve.\n  - Brands are now complete.\n- In-line document tests.\n- Correct major error of `card_brand/1` passing CodePoints to `card_brand/2`.\n- Identify PAN starting just 65 as Discover, vs. RuPay or Troy.\n- Generate documentation.","ref":"changelog.html#0-2-0-2023-08-07-wip","title":"0.2.0 - 2023-08-07 WIP - CHANGELOG","type":"extras"},{"doc":"- Add guards to `card_brand`.\n- Rough move to mix project, tests are functional.","ref":"changelog.html#v0-1-0-2023-08-05-wip","title":"v0.1.0 - 2023-08-05 WIP - CHANGELOG","type":"extras"},{"doc":"- Make `pan_length` first parameter of `pan_range`.\n- China UnionPay, China T-Union, Diners Club, Diners Club International\n- JCB, Maestro, Maestro UK, Visa Electron\n- BORICA, Humo, InstaPayment, InterPayment, Mir, Napas, UATP, UzCard","ref":"changelog.html#v0-0-3-2023-08-04-wip","title":"v0.0.3 - 2023-08-04 WIP - CHANGELOG","type":"extras"},{"doc":"- Initial release.\n- American Express, Discover, Mastercard, and Visa.","ref":"changelog.html#v0-0-2-2023-08-03-wip","title":"v0.0.2 - 2023-08-03 WIP - CHANGELOG","type":"extras"},{"doc":"# Simple Card Brand\n\nDetermine a payment card's brand from the leading digits and length of the account number (PAN).\n\nUses the rules documented on [Wikipedia](https://en.wikipedia.org/wiki/Payment_card_number).","ref":"readme.html","title":"Simple Card Brand","type":"extras"},{"doc":"- American Express (:americanexpress)\n- BORICA (:borica)\n- China T-Union (:chinatunion)\n- China UnionPay (:chinaunionpay)\n- Dankort (:dankort)\n- Diners Club (:dinersclub)\n- Diners Club International (:dinersclubinternational)\n- Discover (:discover)\n- GPN (:gpn)\n- Humo (:humo)\n- InstaPayment (:instapayment)\n- InterPayment (:interpayment)\n- JCB: (:jcb)\n- LankaPay: (:lankapay)\n- Maestro (:maestro)\n- Maestro UK (:maestrouk)\n- Mastercard (:mastercard)\n- Mir (:mir)\n- Napas (:napas)\n- RuPay (:rupay)\n- Troy (:troy)\n- UATP (:uatp)\n- UkrCard (:ukrcard)\n- UzCard (:uzcard)\n- Verve (:verve)\n- Visa (:visa)\n- Visa Electron (:visaelectron)\n\n#","ref":"readme.html#card-brands","title":"Card Brands - Simple Card Brand","type":"extras"},{"doc":"The [Wikipedia](https://en.wikipedia.org/wiki/Payment_card_number) page has several account number range conflicts that need to be researched.\n\n- 65 is always recognized as Discover.\n  Overrides RuPay and Troy.\n\n- 6759 is documented as both Maestro and Maestro UK.\n  - Recognized as Maestro UK.\n\n- 54 is documented as both Diners Club in the US and Mastercard.\n  - Recognized as Diners Club.","ref":"readme.html#conflicts","title":"Conflicts - Simple Card Brand","type":"extras"},{"doc":"- mix format\n- mix test\n- mix credo","ref":"readme.html#mix-commands","title":"Mix Commands - Simple Card Brand","type":"extras"},{"doc":"TO DO\n\nIf [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `simplecardbrand` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:simplecardbrand, \"~> 0.1.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation","title":"Installation - Simple Card Brand","type":"extras"}]}